ComplexNumber

Enum ComplexNumber 

pub enum ComplexNumber {
    Cartesian {
        re: f64,
        im: f64,
    },
    Polar {
        r: f64,
        theta: f64,
    },
}
Representation of a complex number.

This is intended to be used as means for parsing user input, not for doing calculations. So ComplexNumber does not implement any math operations, but supports the conversion to Complex64.

Variants



Cartesian

Fields

re: f64
im: f64


Polar

Fields

theta: f64